@@ -1,29 +1,8 @@
---[[
- * MIT License
- *
- * Copyright (c) 2022 Jianhui Zhao <zhaojh329@gmail.com>
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in all
- * copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
---]]
+-- SPDX-License-Identifier: MIT
+-- Author: Jianhui Zhao <zhaojh329@gmail.com>
 
 local buffer = require 'eco.core.bufio'
-local time = require 'eco.time'
+local sys = require 'eco.core.sys'
 local concat = table.concat
 local str_sub = string.sub
 
@@ -85,11 +64,11 @@ function methods:discard(n, timeout)
     local deadtime
 
     if timeout then
-        deadtime = time.now() + timeout
+        deadtime = sys.uptime() + timeout
     end
 
     while skiped < n do
-        local _, err = reader:read2b(b, deadtime and (deadtime - time.now()))
+        local _, err = reader:read2b(b, deadtime and (deadtime - sys.uptime()))
         if err then
             return nil, err, skiped
         end
@@ -144,13 +123,13 @@ function methods:readfull(n, timeout)
     local deadtime
 
     if timeout then
-        deadtime = time.now() + timeout
+        deadtime = sys.uptime() + timeout
     end
 
     local size = b:size()
 
     while n > 0 do
-        local _, err = reader:read2b(b, deadtime and (deadtime - time.now()))
+        local _, err = reader:read2b(b, deadtime and (deadtime - sys.uptime()))
         if err then
             local chunk = b:read(n)
             data[#data + 1] = chunk
@@ -182,7 +161,7 @@ function methods:readline(timeout)
     local deadtime
 
     if timeout then
-        deadtime = time.now() + timeout
+        deadtime = sys.uptime() + timeout
     end
 
     local data = {}
@@ -213,7 +192,7 @@ function methods:readline(timeout)
             data[#data + 1] = b:read()
         end
 
-        local _, err = reader:read2b(b, deadtime and (deadtime - time.now()))
+        local _, err = reader:read2b(b, deadtime and (deadtime - sys.uptime()))
         if err then
             data[#data + 1] = b:read()
             return nil, err, concat(data)
