@@ -1,25 +1,6 @@
+/* SPDX-License-Identifier: MIT */
 /*
- * MIT License
- *
- * Copyright (c) 2022 Jianhui Zhao <zhaojh329@gmail.com>
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in all
- * copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
+ * Author: Jianhui Zhao <zhaojh329@gmail.com>
  */
 
 #include <stdlib.h>
@@ -96,8 +77,11 @@ static void eco_resume(lua_State *L, lua_State *co, int narg)
 {
 #if LUA_VERSION_NUM < 502
     int status = lua_resume(co, narg);
-#else
+#elif LUA_VERSION_NUM < 504
     int status = lua_resume(co, L, narg);
+#else
+    int nres;
+    int status = lua_resume(co, L, narg, &nres);
 #endif
     switch (status) {
     case 0: /* dead */
@@ -144,7 +128,7 @@ static int eco_count(lua_State *L)
     lua_rawget(L,            LUA_REGISTRYINDEX);
 
     lua_pushnil(L);
-    while ( lua_next(L, -2) != 0 ) {
+    while (lua_next(L, -2) != 0) {
         count++;
         lua_pop(L, 1);
     }
