@@ -1,30 +1,9 @@
---[[
- * MIT License
- *
- * Copyright (c) 2022 Jianhui Zhao <zhaojh329@gmail.com>
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in all
- * copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
---]]
+-- SPDX-License-Identifier: MIT
+-- Author: Jianhui Zhao <zhaojh329@gmail.com>
 
 local socket = require 'eco.socket'
+local sys = require 'eco.core.sys'
 local file = require 'eco.file'
-local time = require 'eco.time'
 local ssl = require 'eco.ssl'
 local dns = require 'eco.dns'
 local log = require 'eco.log'
@@ -274,7 +253,7 @@ local function send_http_request(s, method, path, headers, body)
 end
 
 local function recv_status_line(s, deadtime)
-    local data, err = s:recv('*l', deadtime - time.now())
+    local data, err = s:recv('*l', deadtime - sys.uptime())
     if not data then
         return nil, err
     end
@@ -291,7 +270,7 @@ local function recv_http_headers(s, deadtime)
     local headers = {}
 
     while true do
-        local data, err = s:recv('*l', deadtime - time.now())
+        local data, err = s:recv('*l', deadtime - sys.uptime())
         if not data then
             return nil, err
         end
@@ -328,7 +307,7 @@ local function body_reader(s, headers)
             local deadtime
 
             if timeout then
-                deadtime = time.now() + timeout
+                deadtime = sys.uptime() + timeout
             end
 
             local body = {}
@@ -336,7 +315,7 @@ local function body_reader(s, headers)
 
             while true do
                 if state == 0 then
-                    local data, err = s:recv('*l', deadtime and deadtime - time.now())
+                    local data, err = s:recv('*l', deadtime and deadtime - sys.uptime())
                     if not data then
                         s:close()
                         return nil, err
@@ -361,7 +340,7 @@ local function body_reader(s, headers)
                         n = content_length
                     end
 
-                    local data, err, partial = s:recvfull(n, deadtime and deadtime - time.now())
+                    local data, err, partial = s:recvfull(n, deadtime and deadtime - sys.uptime())
                     if not data then
                         s:close()
                         if partial then
@@ -380,7 +359,7 @@ local function body_reader(s, headers)
                     body[#body + 1] = data
 
                     if content_length == 0 then
-                        data, err = s:recv('*l', deadtime and deadtime - time.now())
+                        data, err = s:recv('*l', deadtime and deadtime - sys.uptime())
                         if err or data ~= '' then
                             s:close()
                             return concat(body)
@@ -443,7 +422,7 @@ local function do_http_request(s, method, path, headers, body, timeout)
         timeout = 30
     end
 
-    local deadtime = time.now() + timeout
+    local deadtime = sys.uptime() + timeout
 
     local code, status = recv_status_line(s, deadtime)
     if not code then
