@@ -1,25 +1,6 @@
+/* SPDX-License-Identifier: MIT */
 /*
- * MIT License
- *
- * Copyright (c) 2022 Jianhui Zhao <zhaojh329@gmail.com>
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in all
- * copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
+ * Author: Jianhui Zhao <zhaojh329@gmail.com>
  */
 
 #include <stdio.h>
@@ -31,7 +12,7 @@ static int lua_log_set_level(lua_State *L)
 {
     int level = luaL_checkinteger(L, 1);
 
-    log_level(level);
+    set_log_level(level);
 
     return 0;
 }
@@ -39,7 +20,7 @@ static int lua_log_set_level(lua_State *L)
 static void __lua_log(lua_State *L, int priority)
 {
     static char buf[BUFSIZ];
-    size_t room = BUFSIZ - 2;
+    size_t room = BUFSIZ - 1;
     const char *filename = "";
     int line = -1;
     char *pos = buf;
@@ -93,7 +74,6 @@ static void __lua_log(lua_State *L, int priority)
         room -= len;
     }
 
-    *pos++ = '\n';
     *pos = '\0';
 
     if (lua_getstack(L, 1, &ar)) {
