@@ -1,32 +1,11 @@
---[[
- * MIT License
- *
- * Copyright (c) 2022 Jianhui Zhao <zhaojh329@gmail.com>
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in all
- * copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
---]]
+-- SPDX-License-Identifier: MIT
+-- Author: Jianhui Zhao <zhaojh329@gmail.com>
 
 local file = require 'eco.core.file'
 local socket = require 'eco.socket'
 local ssl = require 'eco.core.ssl'
+local sys = require 'eco.core.sys'
 local bufio = require 'eco.bufio'
-local time = require 'eco.time'
 
 local str_sub = string.sub
 local concat = table.concat
@@ -239,7 +218,7 @@ local function ssl_negotiate(mt, deadtime)
             w = iow
         end
 
-        if not w:wait(deadtime - time.now()) then
+        if not w:wait(deadtime - sys.uptime()) then
             return nil, 'handshake timeout'
         end
     end
@@ -360,7 +339,7 @@ local function ssl_setmetatable(ctx, sock, methods, name)
         mt.b = create_bufio(mt)
     end
 
-    local ok, err = ssl_negotiate(mt, time.now() + 3.0)
+    local ok, err = ssl_negotiate(mt, sys.uptime() + 3.0)
     if not ok then
         return nil, err
     end
