@@ -1,27 +1,6 @@
+/* SPDX-License-Identifier: MIT */
 /*
- * MIT License
- *
- * Copyright (c) 2022 Jianhui Zhao <zhaojh329@gmail.com>
- *
- * Reference from: https://git.openwrt.org/?p=project/ubus.git;a=blob;f=lua/ubus.c
- *
- * Permission is hereby granted, free of charge, to any person obtaining a copy
- * of this software and associated documentation files (the "Software"), to deal
- * in the Software without restriction, including without limitation the rights
- * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
- * copies of the Software, and to permit persons to whom the Software is
- * furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included in all
- * copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
- * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
- * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
- * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
- * SOFTWARE.
+ * Author: Jianhui Zhao <zhaojh329@gmail.com>
  */
 
 #include <libubus.h>
@@ -150,7 +129,7 @@ static int __blob_to_lua_table(lua_State *L, struct blob_attr *attr, bool is_arr
         break;
 
     case BLOBMSG_TYPE_INT64:
-        lua_pushuint(L, (double) be64_to_cpu(*(uint64_t *)data));
+        lua_pushint(L, (double) be64_to_cpu(*(uint64_t *)data));
         break;
 
     case BLOBMSG_TYPE_DOUBLE: {
